@@ -28,15 +28,22 @@ from troveclient import utils as trove_utils
 def set_attributes_for_print(instances):
     for instance in instances:
         setattr(instance, 'flavor_id', instance.flavor['id'])
+
         if hasattr(instance, 'volume'):
             setattr(instance, 'size', instance.volume['size'])
         else:
             setattr(instance, 'size', '-')
+
         if hasattr(instance, 'datastore'):
             if instance.datastore.get('version'):
                 setattr(instance, 'datastore_version',
                         instance.datastore['version'])
             setattr(instance, 'datastore', instance.datastore['type'])
+
+        if hasattr(instance, 'ip'):
+            addresses = ', '.join(instance.ip)
+            setattr(instance, 'addresses', addresses)
+
     return instances
 
 
@@ -75,10 +82,10 @@ def set_attributes_for_print_detail(instance):
 class ListDatabaseInstances(command.Lister):
     _description = _("List database instances")
     columns = ['ID', 'Name', 'Datastore', 'Datastore Version', 'Status',
-               'Flavor ID', 'Size', 'Region']
+               'Addresses', 'Flavor ID', 'Size', 'Region']
     admin_columns = [
         'ID', 'Name', 'Tenant ID', 'Datastore', 'Datastore Version', 'Status',
-        'Flavor ID', 'Size'
+        'Addresses', 'Flavor ID', 'Size'
     ]
 
     def get_parser(self, prog_name):
@@ -170,13 +177,21 @@ class DeleteDatabaseInstance(base.TroveDeleter):
             metavar='instance',
             help='Id or name of instance(s).'
         )
+        parser.add_argument(
+            '--force',
+            action="store_true",
+            default=False,
+            help=_('Force delete the instance, will reset the instance status '
+                   'before deleting.'),
+        )
         return parser
 
     def take_action(self, parsed_args):
         db_instances = self.app.client_manager.database.instances
 
         # Used for batch deletion
-        self.delete_func = db_instances.delete
+        self.delete_func = (db_instances.force_delete if parsed_args.force
+                            else db_instances.delete)
         self.resource = 'database instance'
 
         ids = []
@@ -197,7 +212,6 @@ class DeleteDatabaseInstance(base.TroveDeleter):
 
 
 class CreateDatabaseInstance(command.ShowOne):
-
     _description = _("Creates a new database instance.")
 
     def get_parser(self, prog_name):
@@ -412,11 +426,9 @@ class CreateDatabaseInstance(command.ShowOne):
 
 
 class ResetDatabaseInstanceStatus(command.Command):
-
-    _description = _("Set the task status of an instance to NONE if the "
-                     "instance is in BUILD or ERROR state. Resetting task "
-                     "status of an instance in BUILD state will allow "
-                     "the instance to be deleted.")
+    _description = _("Set instance service status to ERROR and clear the "
+                     "current task status. Mark any running backup operations "
+                     "as FAILED.")
 
     def get_parser(self, prog_name):
         parser = super(ResetDatabaseInstanceStatus, self).get_parser(prog_name)
@@ -435,7 +447,6 @@ class ResetDatabaseInstanceStatus(command.Command):
 
 
 class ResizeDatabaseInstanceFlavor(command.Command):
-
     _description = _("Resize an instance with a new flavor")
 
     def get_parser(self, prog_name):
@@ -452,22 +463,21 @@ class ResizeDatabaseInstanceFlavor(command.Command):
             'flavor_id',
             metavar='<flavor_id>',
             type=str,
-            help=_('New flavor of the instance')
+            help=_('New flavor ID of the instance')
         )
         return parser
 
     def take_action(self, parsed_args):
-        db_instances = self.app.client_manager.database.instances
-        db_flavor = self.app.client_manager.database.flavors
-        instance = osc_utils.find_resource(db_instances,
-                                           parsed_args.instance)
-        flavor = osc_utils.find_resource(db_flavor,
-                                         parsed_args.flavor_id)
-        db_instances.resize_instance(instance, flavor)
+        instance_mgr = self.app.client_manager.database.instances
+        instance_id = parsed_args.instance
+
+        if not uuidutils.is_uuid_like(instance_id):
+            instance_id = osc_utils.find_resource(instance_mgr, instance_id)
+
+        instance_mgr.resize_instance(instance_id, parsed_args.flavor_id)
 
 
 class UpgradeDatabaseInstance(command.Command):
-
     _description = _("Upgrades an instance to a new datastore version.")
 
     def get_parser(self, prog_name):
@@ -493,7 +503,6 @@ class UpgradeDatabaseInstance(command.Command):
 
 
 class ResizeDatabaseInstanceVolume(command.Command):
-
     _description = _("Resizes the volume size of an instance.")
 
     def get_parser(self, prog_name):
@@ -523,12 +532,11 @@ class ResizeDatabaseInstanceVolume(command.Command):
 
 
 class ForceDeleteDatabaseInstance(command.Command):
-
     _description = _("Force delete an instance.")
 
     def get_parser(self, prog_name):
-        parser = (super(ForceDeleteDatabaseInstance, self)
-                  .get_parser(prog_name))
+        parser = (
+            super(ForceDeleteDatabaseInstance, self).get_parser(prog_name))
         parser.add_argument(
             'instance',
             metavar='<instance>',
@@ -550,7 +558,6 @@ class ForceDeleteDatabaseInstance(command.Command):
 
 
 class PromoteDatabaseInstanceToReplicaSource(command.Command):
-
     _description = _(
         "Promotes a replica to be the new replica source of its set.")
 
@@ -573,7 +580,6 @@ class PromoteDatabaseInstanceToReplicaSource(command.Command):
 
 
 class RestartDatabaseInstance(command.Command):
-
     _description = _("Restarts an instance.")
 
     def get_parser(self, prog_name):
@@ -596,7 +602,6 @@ class RestartDatabaseInstance(command.Command):
 
 
 class EjectDatabaseInstanceReplicaSource(command.Command):
-
     _description = _("Ejects a replica source from its set.")
 
     def get_parser(self, prog_name):
@@ -618,7 +623,6 @@ class EjectDatabaseInstanceReplicaSource(command.Command):
 
 
 class UpdateDatabaseInstance(command.Command):
-
     _description = _("Updates an instance: Edits name, "
                      "configuration, or replica source.")
 
@@ -674,7 +678,6 @@ class UpdateDatabaseInstance(command.Command):
 
 
 class DetachDatabaseInstanceReplica(command.Command):
-
     _description = _("Detaches a replica instance "
                      "from its replication source.")
 
@@ -694,3 +697,27 @@ class DetachDatabaseInstanceReplica(command.Command):
         instance = osc_utils.find_resource(db_instances,
                                            parsed_args.instance)
         db_instances.edit(instance, detach_replica_source=True)
+
+
+class RebootDatabaseInstance(command.Command):
+    _description = _("Reboots an instance(the Nova server).")
+
+    def get_parser(self, prog_name):
+        parser = super(RebootDatabaseInstance, self).get_parser(prog_name)
+        parser.add_argument(
+            'instance',
+            metavar='<instance>',
+            type=str,
+            help=_('ID or name of the instance.'))
+
+        return parser
+
+    def take_action(self, parsed_args):
+        instance_id = parsed_args.instance
+
+        if not uuidutils.is_uuid_like(instance_id):
+            instance_mgr = self.app.client_manager.database.instances
+            instance_id = osc_utils.find_resource(instance_mgr, instance_id)
+
+        mgmt_instance_mgr = self.app.client_manager.database.mgmt_instances
+        mgmt_instance_mgr.reboot(instance_id)
