@@ -59,14 +59,16 @@ class Backups(base.ManagerWithFind):
         return self._get("/backups/%s" % base.getid(backup),
                          "backup")
 
-    def list(self, limit=None, marker=None, datastore=None):
-        """Get a list of all backups.
-
-        :rtype: list of :class:`Backups`.
-        """
+    def list(self, limit=None, marker=None, datastore=None, instance_id=None,
+             all_projects=False):
+        """Get a list of all backups."""
         query_strings = {}
         if datastore:
-            query_strings = {'datastore': datastore}
+            query_strings["datastore"] = datastore
+        if instance_id:
+            query_strings["instance_id"] = instance_id
+        if all_projects:
+            query_strings["all_projects"] = True
 
         return self._paginated("/backups", "backups", limit, marker,
                                query_strings)
@@ -236,13 +238,18 @@ class Backups(base.ManagerWithFind):
         def mistral_execution_generator():
             m = marker
             while True:
-                the_list = mistral_client.executions.list(marker=m, limit=50,
-                                                          sort_dirs='desc')
-                if the_list:
-                    for the_item in the_list:
-                        yield the_item
-                    m = the_list[-1].id
-                else:
+                try:
+                    the_list = mistral_client.executions.list(
+                        marker=m, limit=50,
+                        sort_dirs='desc'
+                    )
+                    if the_list:
+                        for the_item in the_list:
+                            yield the_item
+                        m = the_list[-1].id
+                    else:
+                        return
+                except StopIteration:
                     return
 
         def execution_list_generator():
